Discover Packages
github.com/sageil/kodacode
internal
textdiff
package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: Jun 8, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package textdiff renders compact previews of text mutations.
func LineStats(preview Preview ) (added, removed int )
type Preview struct {
OldStartLine int `json:"old_start_line,omitempty"`
NewStartLine int `json:"new_start_line,omitempty"`
Ops []PreviewOp `json:"ops,omitempty"`
}
type PreviewOp struct {
Kind OpKind `json:"kind,omitempty"`
Text string `json:"text,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.