Documentation
¶
Overview ¶
Package textutil provides shared text accumulation and truncation helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppendRuneTail ¶
AppendRuneTail appends chunk and keeps the last limit runes.
Types ¶
type StringAccumulator ¶
type StringAccumulator struct {
// contains filtered or unexported fields
}
StringAccumulator appends to a seeded string without repeatedly copying the full previously-built value on every delta.
func (*StringAccumulator) Append ¶
func (a *StringAccumulator) Append(current, chunk string) string
func (*StringAccumulator) Reset ¶
func (a *StringAccumulator) Reset()
Click to show internal directories.
Click to hide internal directories.